#
# spec file for package ft2-clone
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ft2-clone
Version:        1.73
Release:        1.1
Summary:        Fasttracker II clone
License:        BSD-3-Clause AND CC-BY-NC-SA-4.0
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://16-bits.org/ft2.php
#Git-Clone:     https://github.com/8bitbubsy/ft2-clone.git
Source:         https://github.com/8bitbubsy/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  icns-utils
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(sdl2)
Provides:       bundled(rtmidi)

%description
Multi-platform clone of the classic music making software
Fasttracker II. It can load XM, MOD, S3M, STM module files.

%prep
%setup -q
icns2png -x "release/macos/ft2-clone-macos.app/Contents/Resources/ft2-clone-macos.icns"
rm -R src/libflac

%build
%cmake -DEXTERNAL_LIBFLAC=ON
%cmake_build

%install
%cmake_install

install -Dpm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dpm 0644 ft2-clone-macos_512x512x32.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%license LICENSE LICENSES.txt src/gfxdata/bmp/LICENSE.txt
%doc README.md release/problems.txt
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.73
  * Sample editor: Shift + mouse-wheel = scroll sample data view
- Update to version 1.72
  * Block Cut (ALT+F3) and Block Copy (ALT+F4) was broken in v1.70
* Wed Oct  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.71
  * CTRL+A/ALT+A keybindings were swapped.
- Update to version 1.70
  * Bugfix: Shrink Pattern ("Srnk.") could lead to a pattern
    length of 0.
  * Better variable sanitation for some pattern editing routines,
    may (?) prevent some rare crashes.
  * CTRL+F5 (Paste Pattern) had wrong button names in its
    message box when asking to adjust the pattern length after
    pasting.
  * Changed the above message box text to be easier to understand.
  * Removed audio dithering for 16-bit audio bit depth mode. It
    seemed to be wrongly implemented anyway.
  * Some small changes done to the about screen.
  * Code cleanup.
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.69
  Bugfixes
  * The 'pattern expand' feature was heavily broken and would mess
    up the pattern data (and potentially crash the program).
  * The program crash message could overflow and not show the full
    text on some system
- Update to version 1.68
  * De-minimize window (if minimized) and set focus after
    drag n' drop of file.
- Update to version 1.67
  * The song-to-WAV export screen now defaults to the tracker's bit
    depth and audio rate. This was actually the behavior for
    earlier versions of the FT2 clone, but I decided to change it
    back.
  * The song-to-WAV exporter now allows rates up to 384kHz.
  * Alpha-based fade in for the about screen content.
  * Some small text string changes (config and song-to-WAV export
    screen)
* Sat Apr 15 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.66
  * Added a 16 point sinc interpolation option (higher quality).
  * Changed some settings for the default configuration:
    1. Palette theme = Dark mode
    2. Scopes = Lined
    Note: Your existing configuration will not be changed!
  * Changed the layout a little in the Config section (Audio /
    "I/O Devices")
  * Removed the 192kHz audio output setting. This was a bit
    extreme to begin with. Note: You can still select this rate
    when exporting songs to WAV.
* Sat Mar  4 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.65
  * Quick fix for volume ramp delta.
- Update to version 1.64
  * Increased number of precision bits for song BPM, playback time
    counter and audio->video syncing. This is a minor change and
    does very little in practice as the previous precision was
    already quite good.
  * Audio/video sync timestamps are reset every half an hour to
    prevent possible sync drifting after several hours of playing
    a song without a single song stop (resets timestamp) in-between
  * The HPC timers are reset every half an hour instead of every
    hour. Video (if no vsync) and the scopes use these timers.
  * Small code refactor for how the song is timed/ticked. Longer
    song-to-WAV renders may have a filesize change of a few bytes,
    but this is actually more correct.
* Tue Feb 14 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.63
- Build with system-wide flac
- Use pkg-config style dependencies
  Sat Oct  9 14:04:02 UTC 2021 - Arachnos
- Initial package with Fasttracker II clone v1.47
